@@ -20,18 +20,20 @@ my $files_being_mocked;
 
 =head1 NAME
 
-Test::MockFile::FileHandle - Provides a class for L<Test::MockFile> to tie to on B<open> or B<sysopen>.
+Test::MockFile::FileHandle - Provides a class for L<Test::MockFile> to
+tie to on B<open> or B<sysopen>.
 
 =head1 VERSION
 
-Version 0.027
+Version 0.028
 
 =cut
 
 =head1 SYNOPSIS
 
-This is a helper class for L<Test::MockFile>. It leverages data in the Test::MockFile namespace but
-lives in its own package since it is the class that file handles are tied to when created in L<Test::MockFile>
+This is a helper class for L<Test::MockFile>. It leverages data in the
+Test::MockFile namespace but lives in its own package since it is the
+class that file handles are tied to when created in L<Test::MockFile>
 
     use Test::MockFile::FileHandle;
     tie *{ $_[0] }, 'Test::MockFile::FileHandle', $abs_path, $rw;
@@ -47,10 +49,13 @@ No exports are provided by this module.
 
 Args: ($class, $file, $mode)
 
-Returns a blessed object for L<Test::MockFile> to tie against. There are no error conditions handled here.
+Returns a blessed object for L<Test::MockFile> to tie against. There
+are no error conditions handled here.
 
-One of the object variables tracked here is a pointer to the file contents in C<%Test::MockFile::files_being_mocked>.
-In order to allow MockFiles to be DESTROYED when they go out of scope, we have to weaken this pointer.
+One of the object variables tracked here is a pointer to the file
+contents in C<%Test::MockFile::files_being_mocked>. In order to allow
+MockFiles to be DESTROYED when they go out of scope, we have to weaken
+this pointer.
 
 See L<Test::MockFile> for more info.
 
@@ -77,11 +82,14 @@ sub TIEHANDLE {
 
 =head2 PRINT
 
-This method will be triggered every time the tied handle is printed to with the print() or say() functions.
-Beyond its self reference it also expects the list that was passed to the print function.
+This method will be triggered every time the tied handle is printed to
+with the print() or say() functions. Beyond its self reference it also
+expects the list that was passed to the print function.
 
-We append to C<$Test::MockFile::files_being_mocked{$file}->{'contents'}> with what was sent. If the file
-handle wasn't opened in a read mode, then this call with throw EBADF via $!
+We append to
+C<$Test::MockFile::files_being_mocked{$file}->{'contents'}> with what
+was sent. If the file handle wasn't opened in a read mode, then this
+call with throw EBADF via $!
 
 =cut
 
@@ -108,8 +116,9 @@ sub PRINT {
 
 =head2 PRINTF
 
-This method will be triggered every time the tied handle is printed to with the printf() function.
-Beyond its self reference it also expects the format and list that was passed to the printf function.
+This method will be triggered every time the tied handle is printed to
+with the printf() function. Beyond its self reference it also expects
+the format and list that was passed to the printf function.
 
 We use sprintf to format the output and then it is sent to L<PRINT>
 
@@ -124,12 +133,14 @@ sub PRINTF {
 
 =head2 WRITE
 
-This method will be called when the handle is written to via the syswrite function.
+This method will be called when the handle is written to via the
+syswrite function.
 
 Arguments passed are:C<( $self, $buf, $len, $offset )>
 
-This is one of the more complicated functions to mimic properly because $len and $offset have to be taken into
-account. Reviewing how syswrite works reveals there are all sorts of weird corner cases.
+This is one of the more complicated functions to mimic properly because
+$len and $offset have to be taken into account. Reviewing how syswrite
+works reveals there are all sorts of weird corner cases.
 
 =cut
 
@@ -166,10 +177,12 @@ sub WRITE {
 
 =head2 READLINE
 
-This method is called when the handle is read via <HANDLE> or readline HANDLE.
+This method is called when the handle is read via <HANDLE> or readline
+HANDLE.
 
-Based on the numeric location we are in the file (tell), we read until the EOF separator (C<$/>) is seen.
-tell is updated after the line is read. undef is returned if tell is already at EOF.
+Based on the numeric location we are in the file (tell), we read until
+the EOF separator (C<$/>) is seen. tell is updated after the line is
+read. undef is returned if tell is already at EOF.
 
 =cut
 
@@ -211,10 +224,13 @@ sub READLINE {
 
 =head2 GETC
 
-B<UNIMPLEMENTED>: Open a ticket in L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need this feature.
+B<UNIMPLEMENTED>: Open a ticket in
+L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need
+this feature.
 
-This method will be called when the getc function is called.
-It reads 1 character out of contents and adds 1 to tell. The character is returned.
+This method will be called when the getc function is called. It reads 1
+character out of contents and adds 1 to tell. The character is
+returned.
 
 =cut
 
@@ -228,8 +244,9 @@ sub GETC {
 
 Arguments passed are:C<( $self, $file_handle, $len, $offset )>
 
-This method will be called when the handle is read from via the read or sysread functions.
-Based on C<$offset> and C<$len>, it's possible to end up with some really weird strings with null bytes in them.
+This method will be called when the handle is read from via the read or
+sysread functions. Based on C<$offset> and C<$len>, it's possible to
+end up with some really weird strings with null bytes in them.
 
 =cut
 
@@ -259,8 +276,9 @@ sub READ {
 
 =head2 CLOSE
 
-This method will be called when the handle is closed via the close function.
-The object is untied and the file contents (weak reference) is removed. Further calls to this object should fail.
+This method will be called when the handle is closed via the close
+function. The object is untied and the file contents (weak reference)
+is removed. Further calls to this object should fail.
 
 =cut
 
@@ -275,11 +293,13 @@ sub CLOSE {
 
 =head2 UNTIE
 
-As with the other types of ties, this method will be called when untie happens.
-It may be appropriate to "auto CLOSE" when this occurs. See The untie Gotcha below.
+As with the other types of ties, this method will be called when untie
+happens. It may be appropriate to "auto CLOSE" when this occurs. See
+The untie Gotcha below.
 
-What's strange about the development of this class is that we were unable to determine how to trigger this call.
-At the moment, the call is just redirected to CLOSE.
+What's strange about the development of this class is that we were
+unable to determine how to trigger this call. At the moment, the call
+is just redirected to CLOSE.
 
 =cut
 
@@ -292,8 +312,9 @@ sub UNTIE {
 
 =head2 DESTROY
 
-As with the other types of ties, this method will be called when the tied handle is about
-to be destroyed. This is useful for debugging and possibly cleaning up.
+As with the other types of ties, this method will be called when the
+tied handle is about to be destroyed. This is useful for debugging and
+possibly cleaning up.
 
 At the moment, the call is just redirected to CLOSE.
 
@@ -307,8 +328,8 @@ sub DESTROY {
 
 =head2 EOF
 
-This method will be called when the eof function is called.
-Based on C<$self-E<gt>{'tell'}>, we determine if we're at EOF.
+This method will be called when the eof function is called. Based on
+C<$self-E<gt>{'tell'}>, we determine if we're at EOF.
 
 =cut
 
@@ -323,9 +344,13 @@ sub EOF {
 
 =head2 BINMODE
 
-B<UNIMPLEMENTED>: Open a ticket in L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need this feature.
+B<UNIMPLEMENTED>: Open a ticket in
+L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need
+this feature.
 
-No L<perldoc documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles> exists on this method.
+No L<perldoc
+documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles>
+exists on this method.
 
 =cut
 
@@ -336,9 +361,13 @@ sub BINMODE {
 
 =head2 OPEN
 
-B<UNIMPLEMENTED>: Open a ticket in L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need this feature.
+B<UNIMPLEMENTED>: Open a ticket in
+L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need
+this feature.
 
-No L<perldoc documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles> exists on this method.
+No L<perldoc
+documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles>
+exists on this method.
 
 =cut
 
@@ -349,9 +378,13 @@ sub OPEN {
 
 =head2 FILENO
 
-B<UNIMPLEMENTED>: Open a ticket in L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need this feature.
+B<UNIMPLEMENTED>: Open a ticket in
+L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need
+this feature.
 
-No L<perldoc documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles> exists on this method.
+No L<perldoc
+documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles>
+exists on this method.
 
 =cut
 
@@ -364,11 +397,15 @@ sub FILENO {
 
 Arguments passed are:C<( $self, $pos, $whence )>
 
-Moves the location of our current tell location. 
+Moves the location of our current tell location.
 
-B<$whence is UNIMPLEMENTED>: Open a ticket in L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need this feature.
+B<$whence is UNIMPLEMENTED>: Open a ticket in
+L<github|https://github.com/cpanelinc/Test-MockFile/issues> if you need
+this feature.
 
-No L<perldoc documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles> exists on this method.
+No L<perldoc
+documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles>
+exists on this method.
 
 =cut
 
@@ -388,9 +425,12 @@ sub SEEK {
 
 =head2 TELL
 
-Returns the numeric location we are in the file. The C<TELL> tells us where we are in the file contents.
+Returns the numeric location we are in the file. The C<TELL> tells us
+where we are in the file contents.
 
-No L<perldoc documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles> exists on this method.
+No L<perldoc
+documentation|http://perldoc.perl.org/perltie.html#Tying-FileHandles>
+exists on this method.
 
 =cut
 
